@@ -18,7 +18,7 @@ Yahoo::Marketing::BasicReportService - an object that provides access to Yahoo M
 
 See EWS documentation online for available SOAP methods:
 
-http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/services/BasicReportService.asp
+L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/services/BasicReportService.asp>
 
 Also see perldoc Yahoo::Marketing::Service for functionality common to all service modules.
 
